#include <qfile.h>
#include <qtextstream.h>

#include <kdebug.h>
#include <klistview.h>

#include "domtreepart.h"
#include "domtreepart.moc"

DOMTreePart::DOMTreePart( QWidget *parent, const char *name )
{
    view = new KListView( parent, name ? name : "DOMTreePart" );
    view->setAlternateBackground( QColor(0xcc, 0xcc, 0xee) );
    view->setRootIsDecorated( true );
    view->addColumn( "Node", /*sidebar->width()*/ 100 );
    view->setResizeMode( QListView::LastColumn );
    view->setSorting( -1 );

    setWidget( view );
    // setXMLFile( "domtreepartui.rc" );
}

DOMTreePart::~DOMTreePart()
{
}

bool DOMTreePart::openFile()
{
    view->clear();
    QFile f( filename() );
    QDomDocument doc( "doc" );
    if ( !doc.setContent( &f ) ) {
	kdDebug() << "Error loading QDomDocument from " << filename() << endl;
    }

    QDomElement root = doc.documentElement();
    buildTree( root );

    return true;
}

void DOMTreePart::buildTree( const QDomElement &node )
{
    rootNode = node;
    KListViewItem *rootItem = createItem( 0, node );

    for ( QDomNode n = node.firstChild(); !n.isNull(); n = n.nextSibling() )
	processChild( rootItem, n );
}

void DOMTreePart::processChild( KListViewItem *i, const QDomNode &n )
{
    QDomNode node( n );
    if ( node.isElement() )
	buildBranch( i, node.toElement() );
    else if ( node.isDocumentType() )
	buildBranch( i, node.toDocumentType() );
    else if ( node.isProcessingInstruction() )
	buildBranch( i, node.toProcessingInstruction() );
    else if ( node.isComment() )
	buildBranch( i, node.toComment() );
    else if ( node.isText() )
	buildBranch( i, node.toText() );
}

void DOMTreePart::buildBranch( KListViewItem *parent, const QDomElement &node )
{
    KListViewItem *item = createItem( parent, node );

    for ( QDomNode n = node.firstChild(); !n.isNull(); n = n.nextSibling() )
	processChild( item, n );
}

void DOMTreePart::buildBranch( KListViewItem *parent, const QDomDocumentType node )
{
    KListViewItem *item = createItem( parent, node );

    for ( QDomNode n = node.firstChild(); !n.isNull(); n = n.nextSibling() )
	processChild( item, n );
}

void DOMTreePart::buildBranch( KListViewItem *parent, const QDomProcessingInstruction &node )
{
    KListViewItem *item = createItem( parent, node );

    for ( QDomNode n = node.firstChild(); !n.isNull(); n = n.nextSibling() )
	processChild( item, n );
}

void DOMTreePart::buildBranch( KListViewItem *parent, const QDomText &node )
{
    KListViewItem *item = createItem( parent, node );

    for ( QDomNode n = node.firstChild(); !n.isNull(); n = n.nextSibling() )
	processChild( item, n );
}

void DOMTreePart::buildBranch( KListViewItem *parent, const QDomComment &node )
{
    KListViewItem *item = createItem( parent, node );

    for ( QDomNode n = node.firstChild(); !n.isNull(); n = n.nextSibling() )
	processChild( item, n );
}

//
// Factory methods
//

KListViewItem *DOMTreePart::createItem( KListViewItem *parent, const QDomElement &node )
{
    KListViewItem *i;
    if ( parent )
	i = new KListViewItem( parent, node.tagName() );
    else
	i = new KListViewItem( view, node.tagName() );

    i->setOpen( true );

    return i;
}

KListViewItem *DOMTreePart::createItem( KListViewItem *parent, const QDomDocumentType &node )
{
    KListViewItem *i;
    if ( parent )
	i = new KListViewItem( parent, node.publicId() );
    else
	i = new KListViewItem( view, node.publicId() );

    i->setOpen( true );

    return i;
}

KListViewItem *DOMTreePart::createItem( KListViewItem *parent, const QDomProcessingInstruction &node )
{
    KListViewItem *i;
    if ( parent )
	i = new KListViewItem( parent, node.data() );
    else
	i = new KListViewItem( view, node.data() );

    i->setOpen( true );

    return i;
}

KListViewItem *DOMTreePart::createItem( KListViewItem *parent, const QDomComment &node )
{
    KListViewItem *i;
    if ( parent )
	i = new KListViewItem( parent, node.data() );
    else
	i = new KListViewItem( view, node.data() );

    i->setOpen( true );

    return i;
}

KListViewItem *DOMTreePart::createItem( KListViewItem *parent, const QDomText &node )
{
    KListViewItem *i;
    if ( parent )
	i = new KListViewItem( parent, node.data() );
    else
	i = new KListViewItem( view, node.data() );

    i->setOpen( true );

    return i;
}

// Local Variables:
// c-basic-offset: 4
// End:



