#include <qfile.h>
#include <qtextedit.h>
#include <qtextstream.h>

#include <kaction.h>
#include <kcolordialog.h>
#include <kdebug.h>
#include <kfiledialog.h>
#include <klocale.h>
#include <kstdaction.h>

#include "richtexteditpart.h"
#include "richtexteditpart.moc"

RichTextEditPart::RichTextEditPart( QWidget *parent, const char *name )
  : KParts::ReadWritePart( parent, name ? name : "RichTextEditPart" )
{
    editor = new QTextEdit( parent, "editor" );
    editor->setReadOnly( false );
    setWidget( editor );

    createActions();
    setXMLFile( "richtexteditpartui.rc" );
    setReadWrite( true );
}


RichTextEditPart::~RichTextEditPart()
{
}

void RichTextEditPart::setReadWrite( bool rw )
{
    editor->setReadOnly( !rw );
    if ( rw ) {
	// Handle modified
    }
    else {
	// Handle modified
    }

    ReadWritePart::setReadWrite( rw );
}

bool RichTextEditPart::openFile()
{
    QFile file( filename() );
    if ( file.open( IO_ReadOnly ) ) {
	QTextStream ts( &file );

	QString s = ts.read();
	editor->setText( s );

	return true;
    }

    return false;
}

bool RichTextEditPart::saveFile()
{
    if ( !isReadWrite() )
	return false;

    // Do save...
    QFile file( filename() );
    if ( file.open( IO_WriteOnly ) ) {
	QTextStream ts( &file );
	ts << editor->text();

	return true;
    }

    return false;
}

void RichTextEditPart::open()
{
    KURL url = KFileDialog::getOpenURL();
    if ( url.isEmpty() )
	return;

    openURL( url );
}

void RichTextEditPart::saveAs()
{
    KURL url = KFileDialog::getSaveURL();
    if ( url.isEmpty() )
	return;

//    saveAs( url );
}

void RichTextEditPart::formatColor()
{
    QColor col;
    int s = KColorDialog::getColor( col, editor->color(), editor );
    if ( s != QDialog::Accepted )
	return;

    editor->setColor( col );
}

void RichTextEditPart::setAlignLeft( bool yes )
{
    if ( yes )
	editor->setAlignment( AlignLeft );
}

void RichTextEditPart::setAlignRight( bool yes )
{
    if ( yes )
	editor->setAlignment( AlignRight );
}

void RichTextEditPart::setAlignCenter( bool yes )
{
    if ( yes )
	editor->setAlignment( AlignCenter );
}

//
// Define Actions
//

void RichTextEditPart::createActions()
{
    //
    // File Actions
    //
    (void) KStdAction::open( this, SLOT( open() ), actionCollection() );
    (void) KStdAction::openRecent( this, SLOT( openURL( const KURL &) ), actionCollection() );
    (void) KStdAction::save( this, SLOT( save() ), actionCollection() );
    (void) KStdAction::saveAs( this, SLOT( saveAs() ), actionCollection() );

    //
    // Edit Actions
    //
    (void) KStdAction::undo( editor, SLOT( undo() ), actionCollection() );
    (void) KStdAction::redo( editor, SLOT( redo() ), actionCollection() );

    (void) KStdAction::cut( editor, SLOT( cut() ), actionCollection() );
    (void) KStdAction::copy( editor, SLOT( copy() ), actionCollection() );
    (void) KStdAction::paste( editor, SLOT( paste() ), actionCollection() );
    (void) new KAction( i18n( "Clear" ), 0,
			editor, SLOT( clear() ),
			actionCollection(), "edit_clear" );

    (void) KStdAction::selectAll( editor, SLOT( selectAll() ), actionCollection() );

    //
    // View Actions
    //
    (void) KStdAction::zoomIn( editor, SLOT( zoomIn() ), actionCollection() );
    (void) KStdAction::zoomOut( editor, SLOT( zoomOut() ), actionCollection() );

    //
    // Character Formatting
    //
    action_bold = new KToggleAction( i18n("&Bold"), "text_bold", CTRL+Key_B,
				     actionCollection(), "format_bold" );
    connect( action_bold, SIGNAL( toggled(bool) ),
	     editor, SLOT( setBold(bool) ) );

    action_italic = new KToggleAction( i18n("&Italic"), "text_italic", CTRL+Key_I,
				       actionCollection(), "format_italic" );
    connect( action_italic, SIGNAL( toggled(bool) ),
	     editor, SLOT( setItalic(bool) ) );

    action_underline = new KToggleAction( i18n("&Underline"), "text_under", CTRL+Key_U,
						  actionCollection(), "format_underline" );
    connect( action_underline, SIGNAL( toggled(bool) ),
	     editor, SLOT( setUnderline(bool) ) );

    (void) new KAction( i18n( "Text &Color..." ), "colorpicker", 0,
			this, SLOT( formatColor() ),
			actionCollection(), "format_color" );

    //
    // Font
    //
    KFontAction *font = new KFontAction( i18n( "&Font"), 0,
					 actionCollection(), "format_font" );
    connect( font, SIGNAL( activated( const QString & ) ),
	     editor, SLOT( setFamily( const QString & ) ) );


    (void) new KFontSizeAction( i18n( "Font &Size"), 0,
				editor, SLOT( setPointSize(int) ),
				actionCollection(), "format_font_size" );

    //
    // Alignment
    //
    action_align_left = new KToggleAction( i18n("Align &Left"), "text_left", 0,
					   actionCollection(), "format_align_left" );   
    connect( action_align_left, SIGNAL( toggled(bool) ),
	     this, SLOT( setAlignLeft(bool) ) );

    action_align_center = new KToggleAction( i18n("Align &Center"), "text_center", 0,
					   actionCollection(), "format_align_center" );
    connect( action_align_center, SIGNAL( toggled(bool) ),
	     this, SLOT( setAlignCenter(bool) ) );

    action_align_right = new KToggleAction( i18n("Align &Right"), "text_right", 0,
					   actionCollection(), "format_align_right" );
    connect( action_align_right, SIGNAL( toggled(bool) ),
	     this, SLOT( setAlignRight(bool) ) );

    action_align_left->setExclusiveGroup( "alignment" );
    action_align_center->setExclusiveGroup( "alignment" );
    action_align_right->setExclusiveGroup( "alignment" );

}




// Local Variables:
// c-basic-offset: 4
// End:



